/*
 * @Author: zc
 * @description 辅助功能-智能外呼任务
 */
import request from '@/utils/request';
/**
 * @description 查询外呼模板列表
 * @param {object} params
 */
export const smartCallOutTemList = (params: object) => {
  return request({
    url: '/api/v1/Ai/callout-template-list',
    method: 'get',
    params
  });
};
/**
 * @description 新增外呼模板
 * @param {object} data
 */
export const smartCallOutTemAdd = (data: object) => {
  return request({
    url: '/api/v1/Ai/add-callouttemplate',
    method: 'post',
    data
  });
};
/**
 * @description 修改外呼模板
 * @param {object} data
 */
export const smartCallOutTemEdit = (data: object) => {
  return request({
    url: '/api/v1/Ai/update-callouttemplate',
    method: 'post',
    data
  });
};
/**
 * @description 删除外呼模板
 * @param {string} id
 */
export const smartCallOutTemDelete = (id: string) => {
  return request({
    url: `/api/v1/Ai/del-callouttemplate?id=${id}`,
    method: 'delete',
  });
};
/**
 * @description 外呼模板启用禁用
 * @param {object} params
 */
export const smartCallOutTemEnable = (params: object) => {
  return request({
    url: '/api/v1/Ai/callouttemplate-enable-unenable',
    method: 'get',
    params
  });
};
/**
 * @description 智能外呼任务列表基础数据
 * @param {object} params
 */
export const smartCallOutTaskBaseData = (params?: object) => {
  return request({
    url: '/api/v1/Ai/callout/list-basedata',
    method: 'get',
    params
  });
};
/**
 * @description 智能外呼任务列表查询
 * @param {object} params
 */
export const smartCallOutTaskList = (params: object) => {
  return request({
    url: '/api/v1/Ai/callout/callouttask-list',
    method: 'get',
    params
  });
};
/**
 * @description 智能外呼任务明细列表查询
 * @param {object} params
 */
export const smartCallOutTaskDetailList = (params: object) => {
  return request({
    url: '/api/v1/Ai/callout/callouttaskdetail',
    method: 'get',
    params
  });
};
/**
 * @description 获取可用外呼模板
 * @param {object} params
 */
export const smartCallOutTemAvailable = (params?: object) => {
  return request({
    url: '/api/v1/Ai/callout/canuse-template',
    method: 'get',
    params
  });
};
/**
 * @description 新增批量外呼任务
 * @param {object} data
 */
export const smartCallOutTaskAdd = (data: object) => {
  return request({
    url: '/api/v1/Ai/callout/add-callout',
    method: 'post',
    data
  });
};
/**
 * @description 终止外呼任务
 * @param {object} data
 */
export const smartCallOutTaskStop = (data: object) => {
  return request({
    url: '/api/v1/Ai/callout/closecallouttask',
    method: 'post',
    data
  });
};
/**
 * @description 启动任务
 * @param {object} data
 */
export const smartCallOutTaskStart = (data: object) => {
  return request({
    url: '/api/v1/Ai/callout/startcallouttask',
    method: 'post',
    data
  });
};
/**
 * @description 暂停任务
 * @param {object} data
 */
export const smartCallOutTaskPause = (data: object) => {
  return request({
    url: '/api/v1/Ai/callout/pausecallouttask',
    method: 'post',
    data
  });
};
/**
 * @description 短信任务列表基础数据
 * @param {object} params
 */
export const smartCallOutSmsBaseData = (params?: object) => {
  return request({
    url: '/api/v1/PushMessage/batchsmstask-basedata',
    method: 'get',
    params
  });
};
/**
 * @description 短信任务列表查询
 * @param {object} params
 */
export const smartCallOutSmsList = (params: object) => {
  return request({
    url: '/api/v1/PushMessage/batchsmstask-query',
    method: 'get',
    params
  });
}
/**
 * @description 新增批量短信任务
 * @param {object} data
 */
export const smartCallOutSmsAdd = (data: object) => {
  return request({
    url: '/api/v1/PushMessage/add-batchsmstask',
    method: 'post',
    data
  });
};
/**
 * @description 终止任务
 * @param {string} id
 */
export const smartCallOutSmsStop = (id: string) => {
  return request({
    url: `/api/v1/PushMessage/stop-batchsmstask?id=${id}`,
    method: 'get',
  });
};
/**
 * @description 获取批量短信任务详情
 * @param {object} params
 */
export const smartCallOutSmsDetail = (params: object) => {
  return request({
    url: '/api/v1/PushMessage/batchsmstask-detail',
    method: 'get',
    params
  });
};
/**
 * @description 获取批量短信任务详情（查询人）
 * @param {object} params
 */
export const smartCallOutSmsDetailQuery = (params: object) => {
  return request({
    url: '/api/v1/PushMessage/batchsmsmtaskdetail-query',
    method: 'get',
    params
  });
};